from .client import *
from .enums import *
from .errors import *
from .models import *

__title__ = "zipline.py"
__author__ = "fretgfr"
__license__ = "MIT"
__copyright__ = "Copyright 2023 fretgfr"
__version__ = "0.4.0"



from enum import Enum


class NameFormat(Enum):
    """Format for the name of uploaded Files"""

    original_name = "name"
    uuid = "uuid"
    date = "date"
    random = "random"
    # gfycat = "gfycat"



__all__ = ("ZiplineError", "UnhandledError", "BadRequest", "Forbidden", "NotFound", "ServerError", "NotAuthenticated")


class ZiplineError(Exception):
    """Base class for Zipline related errors."""

    pass


class UnhandledError(ZiplineError):
    """Raised by the library if the server returns a status code not handled by the lib."""

    pass


class BadRequest(ZiplineError):
    """Server returned a 400 response."""

    pass


class Forbidden(ZiplineError):
    """Server returned a 401 response."""

    pass


class NotFound(ZiplineError):
    """Server returned a 404 response."""


class ServerError(ZiplineError):
    """Server returned a 500 response code."""

    pass


class NotAuthenticated(ZiplineError):
    """Requesting data without an Authorization header"""

    pass
